@@ -83,31 +83,48 @@ class Word2vecDataset(Dataset):
         self.neg_num = neg_num
         self.side_num = side_num
         self.input_file = open(inputFileName, encoding="utf8")
+        self.sample_size=64*1000
+        self.data = []
+        self.weights=[]
+        self.choices = []
+        self.idx = 0
 
     def __len__(self):
         return self.sentences_count
 
     def __getitem__(self, idx):
+        # no shuffle
         while True:
-            line = self.input_file.readline().strip('\n')
-            if not line:
-                self.input_file.seek(0, 0)
-                line = self.input_file.readline().strip('\n')
+            if self.idx%self.sample_size==0:
+                self.data = []
+                self.idx = 0
+                for i in range(self.sample_size):
+                    line = self.input_file.readline().strip('\n')
+                    if not line:
+                        self.input_file.seek(0, 0)
+                        line = self.input_file.readline().strip('\n')
+                    if len(line) > 1:
+                        self.data.append(line)
+                self.weights=[float(x.split(' ')[-1]) for x in self.data]
+                self.choices = np.random.choice(a=self.data, size=self.sample_size, replace=True, p=np.array(self.weights)/sum(self.weights))
+
+            # print(self.data)
+            line = self.choices[self.idx%self.sample_size]
+            words = [x for x in line.split(' ')[:-1]]
+            assert len(words) == self.neg_num+2
+            assert len(words[0].split('_')) == self.side_num+1
+            self.idx += 1
+            return [words[0],words[1],words[2:]]
 
-            if len(line) > 1:
-                words = [x for x in line.split(' ') if len(x)>1]
-                assert len(words) == self.neg_num+2
-                assert len(words[0].split('_')) == self.side_num+1
-                print([words[0],words[1],words[2:]])
-                return [words[0],words[1],words[2:]]
 
     @staticmethod
     def collate(batches):
+        # print(batches)
         all_u = [batch[0] for batch in batches if len(batch) > 0]
         all_u = [list(map(int,x.split('_'))) for x in all_u]
         all_v = [batch[1] for batch in batches if len(batch) > 0]
         all_v = [list(map(int,x.split('_'))) for x in all_v]
         all_neg_v = [batch[2] for batch in batches if len(batch) > 0]
         all_neg_v = [[list(map(int,x.split('_'))) for x in xx] for xx in all_neg_v]
-        print(all_u,all_v,all_neg_v)
+        # print(all_u,all_v,all_neg_v)
         return torch.LongTensor(all_u), torch.LongTensor(all_v), torch.LongTensor(all_neg_v)
