@@ -1,6 +1,6 @@
 import torch
 import torch.optim as optim
-from torch.utils.data import DataLoader
+from torch.utils.data import DataLoader, sampler
 from tqdm import tqdm
 from data_reader import Word2vecDataset
 from model import SkipGramModel
@@ -13,8 +13,8 @@ class Word2VecTrainer:
 
         # self.data = DataReader(input_file, min_count)
         dataset = Word2vecDataset(input_file, side_num=side_num , neg_num=neg_num , sentences_count=sentences_count)
-        self.dataloader = DataLoader(dataset, batch_size=batch_size,
-                                     shuffle=True, num_workers=0, collate_fn=dataset.collate)
+        self.dataloader = DataLoader(dataset, batch_size=batch_size,sampler=sampler.SequentialSampler,
+                                     shuffle=False, num_workers=1, collate_fn=dataset.collate)
 
         self.output_file_name = output_file
         self.emb_size = emb_size
